 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: ModifyBodyRequestWrapper
  * Author:   xxx
  * Date:     2021/8/27 18:18
  */
 package com.fr.plugin.ihca.request;

 import com.fanruan.api.log.LogKit;
 import com.fanruan.api.net.http.HttpKit;
 import com.fanruan.api.util.StringKit;
 import com.fr.general.IOUtils;
 import com.fr.json.JSONObject;
 import com.fr.plugin.ihca.config.IhcaConfig;
 import com.fr.rpc.Invocation;
 import com.fr.rpc.serialization.InvocationSerializer;
 import com.fr.serialization.GZipSerializerWrapper;
 import com.fr.serialization.SerializerHelper;
 import com.fr.third.org.apache.http.entity.StringEntity;

 import javax.servlet.ServletInputStream;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.InputStreamReader;
 import java.util.HashMap;
 import java.util.Map;

 /**
  * <Function Description><br>
  * <ModifyBodyRequestWrapper>
  *
  * @author xxx
  * @since 1.0.0
  */
 public class ModifyBodyRequestWrapper extends HttpServletRequestWrapper {
     public static final String RENAME = "public abstract boolean com.fr.workspace.server.lock.TplOperator.rename(java.lang.String,java.lang.String)";
     public static final String FILE_ADD = "public abstract com.fr.report.entity.VcsEntity com.fr.workspace.server.vcs.VcsOperator.saveVersion(java.lang.String,java.lang.String,java.lang.String,int)";
     public static final String DELETE = "public abstract boolean com.fr.workspace.server.lock.TplOperator.delete(java.lang.String)";
     public static final String DIR_ADD = "public abstract boolean com.fr.workspace.resource.WorkResource.createDirectory(java.lang.String)";
     private final byte[] bodyContent;

     public ModifyBodyRequestWrapper(HttpServletRequest request) {
         super(request);
         this.bodyContent = modifyRequestBody();
     }

     /**
      * @return
      */
     private byte[] modifyRequestBody() {
         try {
             byte[] orgContent = IOUtils.inputStream2Bytes(this.getRequest().getInputStream());
             operation(orgContent);
             return orgContent;
         } catch (Exception e) {
             return null;
         }
     }

     /**
      * 数据处理操作
      *
      * @param content
      * @throws Exception
      */
     private void operation(byte[] content) {
         try {
             Invocation invocation = SerializerHelper.deserialize(content, GZipSerializerWrapper.wrap(InvocationSerializer.getDefault()));
//             LogKit.info("ihca-ModifyBodyRequestWrapper-operation-method:{} parameters:{}", invocation.getMethod(), invocation.getParams());
             JSONObject opData = JSONObject.create();
             if (StringKit.equalsIgnoreCase(invocation.getMethod().toString(), RENAME)) {
                 opData.put("type", "rename");
                 opData.put("node", cutReportlets(invocation.getParams()[0]));
                 opData.put("newName", cutReportlets(invocation.getParams()[1]));
             } else if (StringKit.equalsIgnoreCase(invocation.getMethod().toString(), FILE_ADD)) {
                 opData.put("type", "add");
                 opData.put("user", invocation.getParams()[0]);
                 opData.put("node", cutReportlets(invocation.getParams()[1]));
             } else if (StringKit.equalsIgnoreCase(invocation.getMethod().toString(), DELETE)) {
                 opData.put("type", "delete");
                 opData.put("node", cutReportlets(invocation.getParams()[0]));
             } else if (StringKit.equalsIgnoreCase(invocation.getMethod().toString(), DIR_ADD)) {
                 opData.put("type", "add");
                 opData.put("node", cutReportlets(invocation.getParams()[0]));
             } else {
                 return;
             }
             Map<String, String> headers = new HashMap<>();
             headers.put("Content-Type", "application/json");
//             LogKit.info("ihca-ModifyBodyRequestWrapper-operation-opData:{}", opData.encode());
             StringEntity stringEntity = new StringEntity(opData.encode(), "UTF-8");
             String response = HttpKit.executeAndParse(com.fanruan.api.net.http.rs.HttpRequest.custom()
                     .url(IhcaConfig.getInstance().getUriBase()).post(stringEntity).headers(headers).build());
//             LogKit.info("ihca-ModifyBodyRequestWrapper-operation-response:{}", response);
         } catch (Exception e) {
             LogKit.error(e.getMessage(), e);
         }
     }

     private String cutReportlets(Object filePath) {
         return StringKit.cutStringStartWith(String.valueOf(filePath), "reportlets/");
     }

     @Override
     public ServletInputStream getInputStream() {
         try {
             return new DelegatingServletInputStream(new ByteArrayInputStream(this.bodyContent));
         } catch (Exception e) {
             return null;
         }
     }

     @Override
     public BufferedReader getReader() {
         return new BufferedReader(new InputStreamReader(new ByteArrayInputStream(this.bodyContent)));
     }
 }